Module: FChange

Defined in:
lib/vendor/windows/lib/rb-fchange.rb,
lib/vendor/windows/lib/rb-fchange/event.rb,
lib/vendor/windows/lib/rb-fchange/native.rb,
lib/vendor/windows/lib/rb-fchange/version.rb,
lib/vendor/windows/lib/rb-fchange/watcher.rb,
lib/vendor/windows/lib/rb-fchange/notifier.rb,
lib/vendor/windows/lib/rb-fchange/native/flags.rb

Overview

The root module of the library, which is laid out as so:

  • Notifier -- The main class, where the notifications are set up
  • Watcher -- A watcher for a single file or directory
  • Event -- An filesystem event notification

Defined Under Namespace

Modules: Native Classes: Event, Notifier, Watcher

Constant Summary collapse

VERSION =
"0.0.5"